;*****************************************************************************
;  Calculate the radiance corrected for RSR.
;
;  Inputs:
;  1) rsrf -- RSR data.
;  2) T -- temperature.
;  3) band -- band index.
;  4) numdet -- number of detectors.
;
;  Outputs:
;  1) l_avg -- Result of integral.
;
;  v1 - Chunhui Pan
;  v2 - 5/29/2008 - Jeff McIntire
;*****************************************************************************

FUNCTION get_avg_4, rsrf,T,band,ndet

; Reform rsr and find out how many non zero entries per detector.
rsr_temp=reform(rsrf[band,1,0,*])
ix=WHERE(rsr_temp NE 0,count)

; Get rid of zeros.
rsr=dblarr(9,2,ndet,count)

rsr[band,*,0:ndet-1,0:count-1]=rsrf[band,*,0:ndet-1,0:count-1]

radiance=fltarr(9,ndet,count)
temp1=fltarr(ndet)
temp2=fltarr(ndet)
l_avg=fltarr(ndet)

; Get the Planck radiances.
FOR id=0, ndet-1 DO BEGIN
    FOR j=0, count-1 DO BEGIN
        radiance[band,id,j]=Planck(T,rsr[band,0,id,j])
    ENDFOR
ENDFOR

FOR idet=0, ndet-1 DO BEGIN
    ; If an even number of node points, drop the last point.
    IF 2*fix(count/2)-count EQ 0 THEN BEGIN
        FOR j=1, count-4, 2 DO BEGIN
            temp1[idet]=temp1[idet]+4.*radiance[band,idet,j]*rsr[band,1,idet,j]+2.*radiance[band,idet,j+1]*rsr[band,1,idet,j+1]
            temp2[idet]=temp2[idet]+4.*rsr[band,1,idet,j]+2.*rsr[band,1,idet,j+1]
        ENDFOR
        l_avg[idet]=(radiance[band,idet,0]*rsr[band,1,idet,0]+temp1[idet] $
                     +4.*radiance[band,idet,count-3]*rsr[band,1,idet,count-3] $
                     +radiance[band,idet,count-2]*rsr[band,1,idet,count-2]) $
          /(rsr[band,1,idet,0]+temp2[idet]+4.*rsr[band,1,idet,count-3]+rsr[band,1,idet,count-2])
    ENDIF ELSE BEGIN
        FOR j=1, count-3, 2 DO BEGIN
            temp1[idet]=temp1[idet]+4.*radiance[band,idet,j]*rsr[band,1,idet,j]+2.*radiance[band,idet,j+1]*rsr[band,1,idet,j+1]
            temp2[idet]=temp2[idet]+4.*rsr[band,1,idet,j]+2.*rsr[band,1,idet,j+1]
        ENDFOR
        l_avg[idet]=(radiance[band,0]*rsr[band,1,idet,0]+temp1[idet] $
                     +4.*radiance[band,idet,count-2]*rsr[band,1,idet,count-2] $
                     +radiance[band,idet,count-1]*rsr[band,1,idet,count-1]) $
          /(rsr[band,1,idet,0]+temp2[idet]+4.*rsr[band,1,idet,count-2]+rsr[band,1,idet,count-1])
    ENDELSE
ENDFOR

RETURN,l_avg

END
